@@ -15,8 +15,9 @@
 import numpy as np
 import sklearn as sk
 import xgboost
+import lightgbm as lgbm
 from sklearn.experimental import enable_hist_gradient_boosting
-from sklearn import tree,ensemble,svm,linear_model,neighbors,naive_bayes
+from sklearn import tree,ensemble,svm,linear_model,neighbors,naive_bayes,discriminant_analysis
 
 """
 This python file consist of Class variable models to store detail regarding different model to be utilized for classification problem
@@ -26,7 +27,7 @@ class classifier_config:
     Class variable model consist of a model type key with a list datatype value.
     where the list consist of model class object and dictionary of parameters specific to the model
     """
-    
+
     models={
         "SVC":[
             svm.SVC,
@@ -38,7 +39,7 @@ class classifier_config:
             }
         ],
         "NuSVC":[
-            svm.NuSVC, 
+            svm.NuSVC,
             {
                 "nu":{'float':[0.1,1.0]},
                 "gamma":{"str":['auto','scale']},
@@ -47,12 +48,12 @@ class classifier_config:
             }
         ],
         "LinearSVC":[
-            svm.LinearSVC, 
+            svm.LinearSVC,
             {
                 "C":{"int":[1,3]},
                 "loss":{'str':['hinge', 'squared_hinge']},
                 'tol':{'float':[1e-3,0.1]},
-                "penalty":{'str':['l2']}, 
+                "penalty":{'str':['l2']},
             }
         ],
         "DecisionTreeClassifier":[
@@ -70,7 +71,8 @@ class classifier_config:
                 "criterion":{'str':['gini','entropy']},
                 "n_estimators":{'int':[100,1000]},
                 "max_features":{"str":["auto", "sqrt", "log2"]},
-                "max_depth":{'int':[3,50]}
+                "max_depth":{'int':[3,50]},
+                'n_jobs':{'str':[-1]}
             }
         ],
         "ExtraTreesClassifier":[
@@ -79,7 +81,8 @@ class classifier_config:
                 "criterion":{'str':['gini','entropy']},
                 "n_estimators":{'int':[100,1000]},
                 "max_features":{"str":["auto", "sqrt", "log2"]},
-                "max_depth":{'int':[3,50]}
+                "max_depth":{'int':[3,50]},
+                'n_jobs':{'str':[-1]}
             }
         ],
         "GradientBoostingClassifier":[
@@ -96,11 +99,11 @@ class classifier_config:
         "LogisticRegression":[
             linear_model.LogisticRegression,
             {
-                "penalty":{'str':['l1','l2','elasticnet']}, 
+                "penalty":{'str':['l1','l2','elasticnet']},
                 'tol':{'float':[1e-3,0.1]},
                 "C":{"int":[1,3]},
                 "solver":{'str':['newton-cg','liblinear','lbfgs', 'sag', 'saga']},
-
+                'n_jobs':{'str':[-1]}
             }
         ],
         "RidgeClassifier":[
@@ -126,12 +129,14 @@ class classifier_config:
             xgboost.XGBClassifier,
             {
                 'use_label_encoder':{'bool':[False]},
-                'max_depth': {'int':[3,50]},
+                'max_depth': {'int':[3,20]},
                 'n_estimators': {'int':[100,1000]},
                 'learning_rate': {'float':[1e-3,0.1]},
-                'reg_alpha': {'int':[1, 1.5]},
-                'reg_lambda': {'int':[1, 1.5]},
-                'booster':{'str':['gbtree', 'gblinear','dart']}
+                'reg_alpha': {'float':[1e-3,0.1]},
+                'reg_lambda': {'float':[1e-3,0.1]},
+                'booster':{'str':['gbtree', 'gblinear','dart']},
+                'verbosity':{'str':[0]},
+                'n_jobs':{'str':[1]}
             }
         ],
         "RadiusNeighborsClassifier":[
@@ -192,6 +197,7 @@ class classifier_config:
                 "eta0":{'float':[0.0, 0.1]},
                 "power_t":{'float':[0.01, 0.5]},
                 "epsilon":{'float':[1e-8, 0.1]},
+                'n_jobs':{'str':[-1]}
             }
         ],
         "CategoricalNB":[
@@ -200,7 +206,58 @@ class classifier_config:
                 "alpha":{'float':[1e-2,1.0]},
                 "fit_prior":{'bool':[True,False]},
             }
+        ],
+        "MultinomialNB":[
+            naive_bayes.MultinomialNB,
+            {
+                "alpha":{'float':[1e-2,1.0]},
+                "fit_prior":{'bool':[True,False]},
+            }
+        ],
+        "Perceptron":[
+            linear_model.Perceptron,
+            {
+                "penalty":{"str":['l1','l2','elasticnet']},
+                "alpha":{'float':[1e-4,1.0]},
+                "l1_ratio":{'float':[1e-2,1.0]},
+                "tol":{'float':[1e-3,0.1]},
+                'n_jobs':{'str':[-1]}
+            }
+        ],
+        "LGBMClassifier":[
+            lgbm.LGBMClassifier,
+            {
+                "n_estimators":{'int':[100,1000]},
+                "learning_rate":{'float':[1e-3,1e-2]},
+                "reg_alpha":{'float':[1e-3,0.1]},
+                "reg_lambda":{'float':[1e-3,0.1]},
+                "max_depth":{'int':[3,16]},
+                "num_leaves":{'int':[5,1000]},
+                'bagging_fraction':{'float':[0.1,0.9]},
+                'subsample_freq':{'int':[5,10]},
+                'verbose':{'bool':[-1]},
+                "boosting_type":{'str':['gbdt','dart','rf']}
+            }
+        ], 
+        "LinearDiscriminantAnalysis":[
+              discriminant_analysis.LinearDiscriminantAnalysis,
+              {
+                  "solver":{"str":['lsqr','eigen']},
+                  "shrinkage":{"float":[1e-3,1.0]},
+                  "store_covariance":{"bool":[True,False]},
+                  "tol":{"float":[1e-4,0.1]}
+              }
+        ],
+        "PassiveAggressiveClassifier":[
+              linear_model.PassiveAggressiveClassifier,
+              {
+                  "C":{"float":[1,4]},
+                  "max_iter":{'int':[1000,5000]},
+                  "tol":{'float':[1e-3,0.1]},
+                  "loss":{"str":['hinge','squared_hinge']},
+                  'n_jobs':{'str':[-1]},
+                  "early_stopping":{'bool':[True,False]}
+              }
         ]
-            
     }
 
