@@ -22,10 +22,21 @@ class DictClass:
     YAML=dict()
     ObjectExist= False
     ObjectList=None
+    feature_importance=dict()
+    original_label=dict()
     def __int__(self):
         self.ObjectExist=False
         self.ObjectList=None
         self.YAML={}
+        self.feature_importance=dict()
+        self.original_label=dict()
+
+    def get_encoded_label(self):
+        """
+        return: Dictionary
+        Function returns dictionary of encoded label to orignal label mapping
+        """
+        return self.original_label
     def addKeyValue(self, key,value):
         """
         param1:Class reference/Class object 
@@ -80,4 +91,6 @@ class DictClass:
         self.ObjectExist=False
         self.ObjectList=None
         self.YAML={}
+        self.feature_importance={}
+        self.original_label=dict()
     
