@@ -1,5 +1,6 @@
-from .FileType import getDataFrameType
+from .FileType import get_dataframe_type,write_dataframe
 from .AutoFeatureSelection import *
 from .ProblemType import *
 from .Cleaner import *
-from .YamlGenerator import writeYml
\ No newline at end of file
+from .YamlGenerator import writeYml
+from .progress_bar import *
\ No newline at end of file
